@@ -1,13 +1,16 @@
+from abc import ABCMeta, abstractmethod
 from typing import Any, Dict
 
 from .IRunning import IRunning
 
 
-class IAcquisition(IRunning):
+class IAcquisition(IRunning, metaclass=ABCMeta):
     """The module can acquire a target, usually by accessing a telescope and a camera."""
-    __module__ = 'pyobs.interfaces'
 
-    def acquire_target(self, **kwargs: Any) -> Dict[str, Any]:
+    __module__ = "pyobs.interfaces"
+
+    @abstractmethod
+    async def acquire_target(self, **kwargs: Any) -> Dict[str, Any]:
         """Acquire target at given coordinates.
 
         If no RA/Dec are given, start from current position. Might not work for some implementations that require
@@ -19,7 +22,7 @@ class IAcquisition(IRunning):
         Raises:
             ValueError: If target could not be acquired.
         """
-        raise NotImplementedError
+        ...
 
 
-__all__ = ['IAcquisition']
+__all__ = ["IAcquisition"]
